@@ -27,9 +27,9 @@ class SieveActionAddFlags : public SieveActionAbstractFlags
     Q_OBJECT
 public:
     explicit SieveActionAddFlags(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
-    QString flagsCode() const override;
-    QString help() const override;
-    QUrl href() const override;
+    Q_REQUIRED_RESULT QString flagsCode() const override;
+    Q_REQUIRED_RESULT QString help() const override;
+    Q_REQUIRED_RESULT QUrl href() const override;
 };
 }
 #endif // SIEVEACTIONADDFLAGS_H
