@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,11 +23,13 @@
 #include "widgets/addresslineedit.h"
 
 #include <KLocalizedString>
+#include <KPluginFactory>
+#include <KPluginLoader>
 #include <QLineEdit>
 
 #include <QHBoxLayout>
 #include <QCheckBox>
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 
 using namespace KSieveUi;
@@ -35,8 +37,8 @@ using namespace KSieveUi;
 SieveActionRedirect::SieveActionRedirect(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
     : SieveAction(sieveGraphicalModeWidget, QStringLiteral("redirect"), i18n("Redirect"), parent)
 {
-    mHasCopySupport = sieveCapabilities().contains(QStringLiteral("copy"));
-    mHasListSupport = sieveCapabilities().contains(QStringLiteral("extlists"));
+    mHasCopySupport = sieveCapabilities().contains(QLatin1String("copy"));
+    mHasListSupport = sieveCapabilities().contains(QLatin1String("extlists"));
 }
 
 QWidget *SieveActionRedirect::createParamWidget(QWidget *parent) const
@@ -57,62 +59,61 @@ QWidget *SieveActionRedirect::createParamWidget(QWidget *parent) const
         connect(list, &QCheckBox::clicked, this, &SieveActionRedirect::valueChanged);
         lay->addWidget(list);
     }
-    AddressLineEdit *edit = new AddressLineEdit;
+
+    KSieveUi::AbstractSelectEmailLineEdit *edit = AutoCreateScriptUtil::createSelectEmailsWidget();
     edit->setObjectName(QStringLiteral("RedirectEdit"));
     connect(edit, &AddressLineEdit::valueChanged, this, &SieveActionRedirect::valueChanged);
     lay->addWidget(edit);
     return w;
 }
 
-bool SieveActionRedirect::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
+bool SieveActionRedirect::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("str")) {
-                QLineEdit *edit = w->findChild<AddressLineEdit *>(QStringLiteral("RedirectEdit"));
-                const QString tagValue = e.text();
-                edit->setText(AutoCreateScriptUtil::quoteStr(tagValue));
-            } else if (tagName == QLatin1String("tag")) {
-                const QString tagValue = e.text();
-                if (tagValue == QLatin1String("copy")) {
-                    if (mHasCopySupport) {
-                        QCheckBox *copy = w->findChild<QCheckBox *>(QStringLiteral("copy"));
-                        copy->setChecked(true);
-                    } else {
-                        serverDoesNotSupportFeatures(QStringLiteral("copy"), error);
-                    }
-                } else if (tagValue == QLatin1String("list")) {
-                    if (mHasListSupport) {
-                        QCheckBox *list = w->findChild<QCheckBox *>(QStringLiteral("list"));
-                        list->setChecked(true);
-                    } else {
-                        serverDoesNotSupportFeatures(QStringLiteral("list"), error);
-                    }
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("str")) {
+            AbstractSelectEmailLineEdit *edit = w->findChild<AbstractSelectEmailLineEdit *>(QStringLiteral("RedirectEdit"));
+            const QString tagValue = element.readElementText();
+            edit->setText(AutoCreateScriptUtil::quoteStr(tagValue));
+        } else if (tagName == QLatin1String("tag")) {
+            const QString tagValue = element.readElementText();
+            if (tagValue == QLatin1String("copy")) {
+                if (mHasCopySupport) {
+                    QCheckBox *copy = w->findChild<QCheckBox *>(QStringLiteral("copy"));
+                    copy->setChecked(true);
                 } else {
-                    unknowTagValue(tagValue, error);
-                    qCDebug(LIBKSIEVE_LOG) << " SieveActionRedirect::setParamWidgetValue tagValue unknown" << tagValue;
+                    serverDoesNotSupportFeatures(QStringLiteral("copy"), error);
+                }
+            } else if (tagValue == QLatin1String("list")) {
+                if (mHasListSupport) {
+                    QCheckBox *list = w->findChild<QCheckBox *>(QStringLiteral("list"));
+                    list->setChecked(true);
+                } else {
+                    serverDoesNotSupportFeatures(QStringLiteral("list"), error);
                 }
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else if (tagName == QLatin1String("comment")) {
-                //implement in the future ?
             } else {
-                unknownTag(tagName, error);
-                qCDebug(LIBKSIEVE_LOG) << " SieveActionRedirect::setParamWidgetValue unknown tagName " << tagName;
+                unknowTagValue(tagValue, error);
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionRedirect::setParamWidgetValue tagValue unknown" << tagValue;
             }
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else if (tagName == QLatin1String("comment")) {
+            setComment(element.readElementText());
+            //implement in the future ?
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << " SieveActionRedirect::setParamWidgetValue unknown tagName " << tagName;
         }
-        node = node.nextSibling();
     }
+
     return true;
 }
 
 QString SieveActionRedirect::code(QWidget *w) const
 {
     QString result = QStringLiteral("redirect ");
-    const QLineEdit *edit = w->findChild<AddressLineEdit *>(QStringLiteral("RedirectEdit"));
+    const AbstractSelectEmailLineEdit *edit = w->findChild<AbstractSelectEmailLineEdit *>(QStringLiteral("RedirectEdit"));
     const QString text = edit->text();
 
     if (mHasCopySupport) {
@@ -152,9 +153,11 @@ QStringList SieveActionRedirect::needRequires(QWidget *parent) const
 
 QString SieveActionRedirect::help() const
 {
-    QString helpStr = i18n("The \"redirect\" action is used to send the message to another user at a supplied address, as a mail forwarding feature does.  The \"redirect\" action makes no changes to the message body or existing headers, but it may add new headers.");
+    QString helpStr = i18n(
+        "The \"redirect\" action is used to send the message to another user at a supplied address, as a mail forwarding feature does.  The \"redirect\" action makes no changes to the message body or existing headers, but it may add new headers.");
     if (mHasCopySupport) {
-        helpStr += QLatin1Char('\n') + i18n("If the optional \":copy\" keyword is specified, the tagged command does not cancel the implicit \"keep\". Instead, it redirects a copy in addition to whatever else is happening to the message.");
+        helpStr += QLatin1Char('\n') + i18n(
+            "If the optional \":copy\" keyword is specified, the tagged command does not cancel the implicit \"keep\". Instead, it redirects a copy in addition to whatever else is happening to the message.");
     }
     //TODO add list info
     return helpStr;
@@ -164,4 +167,3 @@ QUrl SieveActionRedirect::href() const
 {
     return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
 }
-
