@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -62,23 +62,22 @@ QString SelectRelationalMatchType::code() const
 
 void SelectRelationalMatchType::initialize()
 {
-    QHBoxLayout *lay = new QHBoxLayout;
+    QHBoxLayout *lay = new QHBoxLayout(this);
     lay->setMargin(0);
-    setLayout(lay);
 
-    mType = new KComboBox;
+    mType = new KComboBox(this);
     mType->addItem(i18n("Value"), QStringLiteral(":value"));
     mType->addItem(i18n("Count"), QStringLiteral(":count"));
     lay->addWidget(mType);
-    connect(mType, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &SelectRelationalMatchType::valueChanged);
+    connect(mType, QOverload<int>::of(&KComboBox::activated), this, &SelectRelationalMatchType::valueChanged);
 
-    mMatch = new KComboBox;
+    mMatch = new KComboBox(this);
     mMatch->addItem(i18n("Greater than"), QStringLiteral("gt"));
     mMatch->addItem(i18n("Greater than or equal"), QStringLiteral("ge"));
     mMatch->addItem(i18n("Less than"), QStringLiteral("lt"));
     mMatch->addItem(i18n("Less than or equal"), QStringLiteral("le"));
     mMatch->addItem(i18n("Equal to"), QStringLiteral("eq"));
     mMatch->addItem(i18n("Not equal to"), QStringLiteral("ne"));
-    connect(mMatch, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &SelectRelationalMatchType::valueChanged);
+    connect(mMatch, QOverload<int>::of(&KComboBox::activated), this, &SelectRelationalMatchType::valueChanged);
     lay->addWidget(mMatch);
 }
