@@ -1,4 +1,4 @@
-/* Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -16,33 +16,31 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef WEBENGINEVIEWER_FINDBAR_MAILWEBENGINEVIEW_H
-#define WEBENGINEVIEWER_FINDBAR_MAILWEBENGINEVIEW_H
+#ifndef WEBENGINEVIEWER_FINDBAR_WEBENGINEVIEW_H
+#define WEBENGINEVIEWER_FINDBAR_WEBENGINEVIEW_H
 
 #include "findbarbase.h"
 #include "ksieveui_export.h"
 
 class QWebEngineView;
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class FindBarWebEngineViewPrivate;
 class KSIEVEUI_EXPORT FindBarWebEngineView : public FindBarBase
 {
     Q_OBJECT
 public:
     explicit FindBarWebEngineView(QWebEngineView *view, QWidget *parent = nullptr);
-    ~FindBarWebEngineView();
+    ~FindBarWebEngineView() override;
 
 private:
-    void clearSelections() Q_DECL_OVERRIDE;
-    void searchText(bool backward, bool isAutoSearch) Q_DECL_OVERRIDE;
-    void updateSensitivity(bool sensitivity) Q_DECL_OVERRIDE;
+    void clearSelections() override;
+    void searchText(bool backward, bool isAutoSearch) override;
+    void updateSensitivity(bool sensitivity) override;
 
 private:
     FindBarWebEngineViewPrivate *const d;
 };
-
 }
 
 #endif
