@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -25,9 +25,8 @@ See README for further information.
 #include "vacationscriptextractor.h"
 #include "sieve-vacation.h"
 
-#include <KLocalizedString>
 #include <QDate>
-#include <QLocale>
+#include <QRegularExpression>
 
 using KMime::Types::AddrSpecList;
 using namespace KSieveUi::Legacy::VacationUtils;
@@ -44,7 +43,7 @@ static inline QString dotstuff(QString s)     // krazy:exclude=passbyvalue
 
 static inline QString stringReplace(QString s)
 {
-    s = s.replace(QRegExp(QLatin1String("[\n\t]+")), QStringLiteral(" "));
+    s = s.replace(QRegularExpression(QStringLiteral("[\n\t]+")), QStringLiteral(" "));
     return s.replace(QLatin1Char('\"'), QStringLiteral("\\\""));
 }
 
@@ -57,14 +56,15 @@ See README for further information.
 bool Legacy::VacationUtils::parseScript(const QString &script, QString &messageText, QString &subject, int &notificationInterval, AddrSpecList &aliases, bool &sendForSpam, QString &domainName,
                                         QDate &startDate, QDate &endDate)
 {
-    if (script.trimmed().isEmpty()) {
+    const QString trimmedScript = script.trimmed();
+    if (trimmedScript.isEmpty()) {
         return false;
     }
 
     // The trimmed() call below prevents parsing errors. The
     // slave somehow omits the last \n, which results in a lone \r at
     // the end, leading to a parse error.
-    const QByteArray scriptUTF8 = script.trimmed().toUtf8();
+    const QByteArray scriptUTF8 = trimmedScript.toUtf8();
     qCDebug(LIBKSIEVE_LOG) << "scriptUtf8 = \"" + scriptUTF8 + "\"";
     KSieve::Parser parser(scriptUTF8.begin(),
                           scriptUTF8.begin() + scriptUTF8.length());
