@@ -29,15 +29,6 @@ using namespace KSieveUi;
 
 VacationCreateScriptJob::VacationCreateScriptJob(QObject *parent)
     : QObject(parent)
-    , mActivate(false)
-    , mScriptActive(false)
-    , mKep14Support(false)
-    , mUserJobRunning(false)
-    , mScriptJobRunning(false)
-    , mSuccess(true)
-    , mSieveJob(nullptr)
-    , mParseUserJob(nullptr)
-    , mCreateJob(nullptr)
 {
 }
 
@@ -109,7 +100,7 @@ void VacationCreateScriptJob::start()
         mUserJobRunning = true;
         QUrl url = mUrl;
         url = url.adjusted(QUrl::RemoveFilename);
-        url.setPath(url.path() + QLatin1String("USER"));
+        url.setPath(url.path() + QLatin1Char('/') + QLatin1String("USER"));
         mParseUserJob = new ParseUserScriptJob(url, this);
         connect(mParseUserJob, &ParseUserScriptJob::finished, this, &VacationCreateScriptJob::slotGotActiveScripts);
         mParseUserJob->start();
