@@ -74,15 +74,15 @@ struct Vacation {
     bool sendForSpam;
 };
 
-QString composeScript(const Vacation &vacation);
+Q_REQUIRED_RESULT QString composeScript(const Vacation &vacation);
 
-KSieveUi::VacationUtils::Vacation parseScript(const QString &script);
+Q_REQUIRED_RESULT KSieveUi::VacationUtils::Vacation parseScript(const QString &script);
 
-QString mergeRequireLine(const QString &script, const QString &scriptUpdate);
+Q_REQUIRED_RESULT QString mergeRequireLine(const QString &script, const QString &scriptUpdate);
 
-QString updateVacationBlock(const QString &oldScript, const QString &newScript);
+Q_REQUIRED_RESULT QString updateVacationBlock(const QString &oldScript, const QString &newScript);
 
-QString mailAction(MailAction action);
+Q_REQUIRED_RESULT QString mailAction(MailAction action);
 }
 }
 
